denymount
=========

> Node.js library to prevent automatic mounting of specific disks on Mac OS X. For Mac OS X >= 10.9.

[![npm version](https://badge.fury.io/js/denymount.svg)](http://badge.fury.io/js/denymount)
[![dependencies](https://david-dm.org/resin-io-modules/denymount.svg)](https://david-dm.org/resin-io-modules/denymount.svg)
[![Build Status](https://travis-ci.org/resin-io-modules/denymount.svg?branch=master)](https://travis-ci.org/resin-io-modules/denymount)

Installation
------------

Install `denymount` by running:

```sh
$ npm install --save denymount
```

Documentation
-------------

<a name="module_denymount..denymount"></a>

### denymount~denymount(disk, handler, callback)
**Kind**: inner method of <code>[denymount](#module_denymount)</code>  
**Summary**: Prevent automatic mounting of an OS X disk  
**Access:** public  

| Param | Type | Description |
| --- | --- | --- |
| disk | <code>String</code> | disk |
| handler | <code>function</code> | handler (callback) |
| callback | <code>function</code> | callback (error) |

**Example**  
```js
denymount('/dev/disk2', function(callback) {
  console.log('While this code runs, /dev/disk2 is ensured to not be auto-mounted');
  return callback(null, 'foo');
}, function(error, message) {
  if (error) {
    throw error;
  }

  console.log(message);
});
```

Tests
-----

Run the test suite by doing:

```sh
$ npm test
```

Development
-----------

`denymount` wraps a native command line utility that must be built with Xcode 7.

If you make edits to the executable source make sure to build it afterwards with:

```sh
$ npm run build
```

This will build and place the compiled executable in the *bin* folder.

The command line utility can be used directly as follows:

```sh
$ ./bin/denymount diskName
```

The programme will keep running until you hit `ctrl+C` (or `SIGINT`/`SIGTERM` if sent to background).

Contribute
----------

- Issue Tracker: [github.com/resin-io-modules/denymount/issues](https://github.com/resin-io-modules/denymount/issues)
- Source Code: [github.com/resin-io-modules/denymount](https://github.com/resin-io-modules/denymount)

Support
-------

If you're having any problem, please [raise an issue](https://github.com/resin-io-modules/denymount/issues/new)
on GitHub and the Resin.io team will be happy to help.

License
-------

*denymount* is free software, and may be redistributed under the terms specified
in the [license](https://github.com/resin-io-modules/denymount/blob/master/LICENSE).
